==> istio-model-v1beta1-6.3.1-sources.jar: io/fabric8/istio/api/security/v1beta1/AuthorizationPolicyListFluent.java <==
package io.fabric8.istio.api.security.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface AuthorizationPolicyListFluent<A extends AuthorizationPolicyListFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public A addToItems(Integer index,AuthorizationPolicy item);
  public A setToItems(Integer index,AuthorizationPolicy item);
  public A addToItems(io.fabric8.istio.api.security.v1beta1.AuthorizationPolicy... items);
  public A addAllToItems(Collection<AuthorizationPolicy> items);
  public A removeFromItems(io.fabric8.istio.api.security.v1beta1.AuthorizationPolicy... items);
  public A removeAllFromItems(Collection<AuthorizationPolicy> items);
  public A removeMatchingFromItems(Predicate<AuthorizationPolicyBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<AuthorizationPolicy> getItems();
  public List<AuthorizationPolicy> buildItems();
  public AuthorizationPolicy buildItem(Integer index);
  public AuthorizationPolicy buildFirstItem();
  public AuthorizationPolicy buildLastItem();
  public AuthorizationPolicy buildMatchingItem(Predicate<AuthorizationPolicyBuilder> predicate);
  public Boolean hasMatchingItem(Predicate<AuthorizationPolicyBuilder> predicate);
  public A withItems(List<AuthorizationPolicy> items);
  public A withItems(io.fabric8.istio.api.security.v1beta1.AuthorizationPolicy... items);
  public Boolean hasItems();
  public AuthorizationPolicyListFluent.ItemsNested<A> addNewItem();
  public AuthorizationPolicyListFluent.ItemsNested<A> addNewItemLike(AuthorizationPolicy item);
  public AuthorizationPolicyListFluent.ItemsNested<A> setNewItemLike(Integer index,AuthorizationPolicy item);
  public AuthorizationPolicyListFluent.ItemsNested<A> editItem(Integer index);
  public AuthorizationPolicyListFluent.ItemsNested<A> editFirstItem();
  public AuthorizationPolicyListFluent.ItemsNested<A> editLastItem();
  public AuthorizationPolicyListFluent.ItemsNested<A> editMatchingItem(Predicate<AuthorizationPolicyBuilder> predicate);
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public ListMeta getMetadata();
  public A withMetadata(ListMeta metadata);
  public Boolean hasMetadata();
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
  public interface ItemsNested<N> extends Nested<N>,AuthorizationPolicyFluent<AuthorizationPolicyListFluent.ItemsNested<N>>{
    public N and();
    public N endItem();
    
  }
  
}

==> istio-model-v1beta1-6.7.1-sources.jar: io/fabric8/istio/api/security/v1beta1/AuthorizationPolicyListFluent.java <==
package io.fabric8.istio.api.security.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface AuthorizationPolicyListFluent<A extends AuthorizationPolicyListFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public A addToItems(int index,AuthorizationPolicy item);
  public A setToItems(int index,AuthorizationPolicy item);
  public A addToItems(io.fabric8.istio.api.security.v1beta1.AuthorizationPolicy... items);
  public A addAllToItems(Collection<AuthorizationPolicy> items);
  public A removeFromItems(io.fabric8.istio.api.security.v1beta1.AuthorizationPolicy... items);
  public A removeAllFromItems(Collection<AuthorizationPolicy> items);
  public A removeMatchingFromItems(Predicate<AuthorizationPolicyBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<AuthorizationPolicy> getItems();
  public List<AuthorizationPolicy> buildItems();
  public AuthorizationPolicy buildItem(int index);
  public AuthorizationPolicy buildFirstItem();
  public AuthorizationPolicy buildLastItem();
  public AuthorizationPolicy buildMatchingItem(Predicate<AuthorizationPolicyBuilder> predicate);
  public Boolean hasMatchingItem(Predicate<AuthorizationPolicyBuilder> predicate);
  public A withItems(List<AuthorizationPolicy> items);
  public A withItems(io.fabric8.istio.api.security.v1beta1.AuthorizationPolicy... items);
  public Boolean hasItems();
  public AuthorizationPolicyListFluent.ItemsNested<A> addNewItem();
  public AuthorizationPolicyListFluent.ItemsNested<A> addNewItemLike(AuthorizationPolicy item);
  public AuthorizationPolicyListFluent.ItemsNested<A> setNewItemLike(int index,AuthorizationPolicy item);
  public AuthorizationPolicyListFluent.ItemsNested<A> editItem(int index);
  public AuthorizationPolicyListFluent.ItemsNested<A> editFirstItem();
  public AuthorizationPolicyListFluent.ItemsNested<A> editLastItem();
  public AuthorizationPolicyListFluent.ItemsNested<A> editMatchingItem(Predicate<AuthorizationPolicyBuilder> predicate);
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public ListMeta getMetadata();
  public A withMetadata(ListMeta metadata);
  public Boolean hasMetadata();
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
  public interface ItemsNested<N> extends Nested<N>,AuthorizationPolicyFluent<AuthorizationPolicyListFluent.ItemsNested<N>>{
    public N and();
    public N endItem();
    
  }
  
}
